import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="sskie", # 모듈 이름
    version="0.3.6", # 버전
    author="knut_urban", # 제작자
    author_email="tnekf0314@ut.ac.kr", # contact
    description="prototype-used-in-sskie", # 모듈 설명
    long_description=open('README.md').read(), # README.md에 보통 모듈 설명을 해놓는다.
    long_description_content_type="text/markdown",
    url="",
    install_requires=[ # 필수 라이브러리들을 포함하는 부분인 것 같음, 다른 방식으로 넣어줄 수 있는지는 알 수 없음
    "pandas",
    "numpy",
    "scipy",
    "geopandas",
    "pydeck",
    "simplejson"
    ],
    package_data={'': ['LICENSE.txt', 'requirements.txt', 'data/마포구_all_store.txt', 'data/마포구_음식업_store.txt', 'data/mapo-gu.geojson']}, # 원하는 파일 포함, 제대로 작동되지 않았음
    include_package_data=True,
    packages = setuptools.find_packages(), # 모듈을 자동으로 찾아줌
    python_requires=">=3.8.6", # 파이썬 최소 요구 버전
)


from .spatial_analysis import Spatial_Clustering

__version__ = '0.3.6'

# 아래 할때는 build, dist, egg 지워야됨 + __version__ 수정
# python setup.py sdist bdist_wheel

# python -m twine upload dist/*

# pypi-AgEIcHlwaS5vcmcCJDQ2MjYwZWQ2LTM1NzctNDU2OS1hZTZlLWM0ZmJlMjhiODZjYgACKlszLCI0MGU1OTEyNi03M2U3LTQwODItYTNkMy0xOWEwYTJiMjUzYjEiXQAABiDnTZmbRUJYPbdvEHdUqVG66qYsklVOOAXryxPUpCOjLQ


